@@ -171,7 +171,7 @@ $(document).ready(function () {
 			var data = {
 				'placeholder_id': this.options.placeholder_id,
 				'plugin_type': item.attr('rel'),
-				'parent_id': this.options.plugin_id,
+				'plugin_parent': this.options.plugin_id,
 				'plugin_language':  this.options.plugin_language
 			};
 
